%{
[x_m, y_m] = markerPos(x, y, N)
NEED SUB-FUNCTION "markerPosInterpol"

overlay markers *_m to distinguish individual plot lines 
distribute markers equally along x-axis
interpolate to get a total number of N markers

Fadri Pestalozzi, 2015
%}

function [x_m, y_m] = markerPos(x, y, N)

%% test values
% x=linspace(1,10,30)';
% y=x.^2;
% N=10;

%%
% markers distributed evenly along x-axis
% x_m = x-values of markers, skip first and last for interpolation
x_start = x(2);
x_end   = x(end-1);

x_m = x_start : (x_end-x_start)/(N-1) : x_end;

% ensure column vector
x_m = x_m(:);

% check total number of markers = N
% N = length(x_m);

%% find x-values of data pairs (x1-x2) surrounding desired x_m -> interpolate to get y_m

% x1(i) < x_m(i)
% x2(i) => x_m(i)

% initialize
x1  = zeros(N,1);   x2  = x1;
y1  = x1;           y2  = x1;
y_m = x1;

% for all marker positions
for i=1:N
    
    x2_idx=find(x>x_m(i),1,'first');
    
    if isempty(x2_idx); x2_idx=N; end
    
    x2(i)=x(x2_idx);
    y2(i)=y(x2_idx);
    
    if x2_idx>1
        x1_idx=x2_idx-1;
    else
        x1_idx=x2_idx;
    end
        
    x1(i)=x(x1_idx);
    y1(i)=y(x1_idx);
    
    y_m(i) = markerPosInterpol(x1(i), x2(i), x_m(i), y1(i), y2(i));
end

end


