%{
% figH=plotYYErrorbar(x1, y1, y1std, x2, y2, y2std, ...
%                     XLabel, Y1Label, Y2Label, ...
%                     XTickLabel, x_w, y1_w, y2_w, noLine)
% 
% NEED SUBFUNCTIONS
% plotPos
% colors
% 
% plot either one or two sets of y-data corresponding to the same x-axis
% 
% If no [x2,y2]-data is supplied to plot_yy, the second y-axis is suppressed 
% 
% The different axis can be limited to a certain range / window (_w)
% 
% If no window input is supplied, the plotting range is fitted to the data
%
% sample input
% XTickLabel = {'aq','2-20','-125','-1000','-1600','-2500','-4000','-6300'}; 
% 
% Fadri Pestalozzi 2017
%}
function figH=plotYYErrorbar(x1, y1, y1std, x2, y2, y2std, ...
                    XLabel, Y1Label, Y2Label, ...
                    XTickLabel, x_w, y1_w, y2_w, noLine)
%% font
markerSize=11;
tic_fontsize = 15;
axis_fontsize = 18;
line_width = 1.5;

%% use default values if no windows (*_w) defined in function call
if ~exist('x_w','var')
    x_w = [0 0];
end

if ~exist('y1_w','var')
    y1_w = [0 0];
end

if ~exist('y2_w','var')
    y2_w = [0 0];
end


%% figure header
figH=figure(1);
plotPos(figH)
colors=plotColors;
hold on; 

%% first y-axis
set(gca,'FontSize',tic_fontsize)

if noLine==1
  errorbar(x1,y1,y1std, 'color',colors(1,:),'marker','<','markersize',markerSize,'linestyle','none','linewidth', line_width)
else
  errorbar(x1,y1,y1std, 'color',colors(1,:),'linestyle','-','linewidth', line_width)
end

% get current ylim
ylim1 = ylim;

% show missing vals, plot on min(y)==x-axis
if any(isnan(y1))
    for i=1:length(y1)
        if isnan(y1(i))
            if exist('y1_w','var')
                plot(x1(i),y1_w(1),'color',[1 0 0],'marker','.','markersize',20)
            else
                plot(x1(i),min(ylim1),'color',[1 0 0],'marker','.','markersize',20)
            end
        end
    end
end

% apply axis window if different than default value [0,0]
if y1_w(2)~=0
    ylim([y1_w(1) y1_w(2)])
end

ylabel(Y1Label,'FontSize',axis_fontsize)


%% change y-axis

%% only one y-axis necessary if either x2 or y2 contain only one value
if length(x2)~=1 && length(y2)~=1

% get current axis handle
ax1 = gca;

% no ticks on first x-axis to prevent double + shifted ticks
set(ax1,'XColor',colors(1,:),'YColor',colors(1,:),'xtick',[])

ax2 = axes('Position',get(ax1,'Position'),...
     'XAxisLocation','bottom',...
     'YAxisLocation','right',...
     'Color','none',...
     'XColor',colors(1,:),'YColor',colors(2,:));
       
linkaxes([ax1 ax2],'x');


%% x-axis and second y-axis
set(gca,'FontSize',tic_fontsize)

xlabel(XLabel,'FontSize',axis_fontsize)
ylabel(Y2Label,'FontSize',axis_fontsize)

hold on

if noLine==1
    errorbar(x2,y2,y2std, 'color',colors(2,:),'marker','>','markersize',markerSize,'linestyle','none','linewidth', line_width,'Parent',ax2)  % 'marker','o',
else
    errorbar(x2,y2,y2std, 'color',colors(2,:),'linestyle','--', 'linewidth', line_width,'Parent',ax2)
end

% get current ylim
ylim2 = ylim;

% show missing vals, plot on min(y)==x-axis
if any(isnan(y2))
    for i=1:length(y2)
        if isnan(y2(i))
            if exist('y2_w','var')
                plot(x2(i),y2_w(1),'color',[1 0 0],'marker','.','markersize',20)
            else
                plot(x2(i),min(ylim2),'color',[1 0 0],'marker','.','markersize',20)
            end
        end
    end
end

%% apply windows and grid
if y2_w(2)~=0
    ylim([y2_w(1) y2_w(2)])
end

if x_w(2)~=0
    xlim([x_w(1) x_w(2)])
end

grid on;

else
%% generate grid if only one y-axis present
    
   grid on; 
end


%% new XTicks
x = 0:length(XTickLabel)-1;
set(gca,'XTick',linspace(x(1),x(end),length(x)))
set(gca,'XTickLabel',XTickLabel)


%% X-Tick locations and limits
Xt = x;
Xl = [0 max(x)];
set(gca,'XTick',Xt,'XLim',Xl);

%% Y-axis-limits
ax = axis;    % Current axis limits
axis(axis);    % Set the axis limit modes (e.g. XLimMode) to manual
Yl = ax(3:4);  % Y-axis limits


%% remove automatic x-ticks from bar plot to replace with rotated ones
set(gca,'XTickLabel','')

% Place rotated text labels instead of default XTickLabels - squeeze in :p
t = text(Xt,Yl(1)*ones(1,length(Xt)),XTickLabel);
set(t,'HorizontalAlignment','right','VerticalAlignment','top', ...
      'Rotation',45,'FontSize',tic_fontsize);

%% reposition xlabel to account for rotated XTickLabels
xl_h = get(gca,'XLabel');
set(xl_h,'Units','characters');

% xlabel_shift=4;
xlabel_shift=3;
xl_pos=get(xl_h,'Position');
set(xl_h,'Position',xl_pos - [0 xlabel_shift 0]);


%% font weight
set(gca,'FontSize',tic_fontsize)

if x_w(2)~=0
    xlim([x_w(1) x_w(2)])
end


end